package
Version:
v0.0.0-...-9feb207
Opens a new window with list of versions in this module.
Published: May 9, 2020
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Get(key string) interface{}
func Set(key string, value interface{})
Source Files
¶
Click to show internal directories.
Click to hide internal directories.